@@ -11,9 +11,12 @@
 
 namespace tatami_r { 
 
+template<typename Input_>
+using I = std::remove_reference_t<std::remove_cv_t<Input_> >;
+
 inline std::string make_to_string(const Rcpp::RObject& str) {
     Rcpp::StringVector as_str(str);
-    if (as_str.size()!=1) { 
+    if (as_str.size() != 1) { 
         throw std::runtime_error("input RObject should contain a single string");
     }
     return Rcpp::as<std::string>(as_str[0]);
@@ -32,6 +35,9 @@ inline std::string get_class_name(const Rcpp::RObject& incoming) {
 
 template<typename Index_>
 Rcpp::IntegerVector increment_indices(const std::vector<Index_>& indices) {
+    // Assume that we've already checked for overflow in length in the UnknownMatrix constructor.
+    // We also know that there won't be any overflow in contents as we know that
+    // extents fit in both int/Index_ after passing through the UnknownMatrix constructor.
     Rcpp::IntegerVector output(indices.begin(), indices.end());
     for (auto& x : output) {
         ++x;
@@ -39,6 +45,14 @@ Rcpp::IntegerVector increment_indices(const std::vector<Index_>& indices) {
     return output;
 }
 
+template<typename Index_>
+Rcpp::IntegerVector consecutive_indices(const Index_ start, const Index_ length) {
+    // Assume that we've already checked for overflow in the UnknownMatrix constructor.
+    Rcpp::IntegerVector output(length);
+    std::iota(output.begin(), output.end(), start + 1);
+    return output;
+}
+
 }
 
 #endif
